from setuptools import setup, find_packages

setup(
    name = 'First_pypi',
    version = '0.1',
    packages = find_packages(),
    install_requires = [
        # Add depenecies here.
        # e.g. `numpy>=1.11.1`
    ],
)
